@@ -6,5 +6,5 @@ boston_dataset, boston_label = load_dataset('boston')
 titanic_dataset, titanic_label = load_dataset('titanic')
 
 def test_correlation():
-    check(correlation, boston_dataset, boston_label)
-    check(correlation, titanic_dataset, titanic_label)
+    assert check(correlation, boston_dataset, boston_label)
+    assert check(correlation, titanic_dataset, titanic_label)
